@@ -83,13 +83,14 @@ HDF5_LOCK = SerializableLock()
 class RadolanArrayWrapper(BackendArray):
     """Wraps array of RADOLAN data."""
 
-    def __init__(self, datastore, array):
+    def __init__(self, datastore, name, array):
         self.datastore = datastore
+        self.name = name
         self.shape = array.shape
         self.dtype = array.dtype
 
     def _getitem(self, key):
-        return self.datastore.ds.data[key]
+        return self.datastore.ds.data[self.name][key]
 
     def __getitem__(self, key):
         return indexing.explicit_indexing_adapter(
@@ -103,7 +104,9 @@ class RadolanArrayWrapper(BackendArray):
 class RadolanDataStore(AbstractDataStore):
     """Implements ``xarray.AbstractDataStore`` read-only API for a RADOLAN files."""
 
-    def __init__(self, filename_or_obj, lock=None, fillmissing=False, copy=False):
+    def __init__(
+        self, filename_or_obj, lock=None, fillmissing=False, copy=False, ancillary=False
+    ):
         if lock is None:
             lock = RADOLAN_LOCK
         self.lock = ensure_lock(lock)
@@ -113,12 +116,18 @@ class RadolanDataStore(AbstractDataStore):
                 _radolan_file,
                 filename_or_obj,
                 lock=lock,
-                kwargs={"fillmissing": fillmissing, "copy": copy},
+                kwargs={
+                    "fillmissing": fillmissing,
+                    "copy": copy,
+                    "ancillary": ancillary,
+                },
             )
         else:
             if isinstance(filename_or_obj, bytes):
                 filename_or_obj = io.BytesIO(filename_or_obj)
-            dataset = _radolan_file(filename_or_obj, fillmissing=fillmissing, copy=copy)
+            dataset = _radolan_file(
+                filename_or_obj, fillmissing=fillmissing, copy=copy, ancillary=ancillary
+            )
             manager = DummyFileManager(dataset)
 
         self._manager = manager
@@ -134,10 +143,13 @@ class RadolanDataStore(AbstractDataStore):
 
     def open_store_variable(self, name, var):
         encoding = {"source": self._filename}
-        if isinstance(var.data, np.ndarray):
-            data = var.data
+        vdata = var.data
+        if isinstance(vdata, np.ndarray):
+            data = vdata
         else:
-            data = indexing.LazilyOuterIndexedArray(RadolanArrayWrapper(self, var.data))
+            data = indexing.LazilyOuterIndexedArray(
+                RadolanArrayWrapper(self, name, vdata)
+            )
         return Variable(var.dimensions, data, var.attributes, encoding)
 
     def get_variables(self):
@@ -176,12 +188,13 @@ class RadolanBackendEntrypoint(BackendEntrypoint):
         decode_timedelta=None,
         fillmissing=False,
         copy=False,
+        ancillary=False,
     ):
-
         store = RadolanDataStore(
             filename_or_obj,
             fillmissing=fillmissing,
             copy=copy,
+            ancillary=ancillary,
         )
         store_entrypoint = StoreBackendEntrypoint()
         with close_on_error(store):
@@ -737,7 +750,7 @@ class CfRadial1BackendEntrypoint(BackendEntrypoint):
         use_cftime=None,
         decode_timedelta=None,
         format=None,
-        group=None,
+        group="/",
     ):
 
         store = NetCDF4DataStore.open(
@@ -759,7 +772,7 @@ class CfRadial1BackendEntrypoint(BackendEntrypoint):
             decode_timedelta=decode_timedelta,
         )
 
-        if group is not None:
+        if group != "/":
             ds = _assign_data_radial(ds, sweep=group)[0]
 
         return ds
@@ -840,7 +853,7 @@ class CfRadial2BackendEntrypoint(BackendEntrypoint):
             ds = ds.assign_coords(site)
             ds.attrs["fixed_angle"] = fixed_angle
             ds = _assign_data_radial2(ds)
-            dim0 = list(set(ds.dims) & {"azimuth", "elevation", "time"})[0]
+            dim0 = list(set(ds.dims) & {"azimuth", "elevation"})[0]
             ds = ds.sortby(dim0)
 
         return ds
@@ -929,7 +942,7 @@ class IrisStore(AbstractDataStore):
         dim = self.root.first_dimension
 
         data = indexing.LazilyOuterIndexedArray(IrisArrayWrapper(self, name, var))
-        encoding = {"group": self._group}
+        encoding = {"group": self._group, "source": self._filename}
 
         mname = iris_mapping.get(name, name)
         mapping = moments_mapping.get(mname, {})
@@ -1190,7 +1203,7 @@ class RainbowStore(AbstractDataStore):
         name = raw["@type"]
 
         data = indexing.LazilyOuterIndexedArray(RainbowArrayWrapper(self, name, raw))
-        encoding = {"group": self._group}
+        encoding = {"group": self._group, "source": self._filename}
 
         vmin = float(raw.get("@min"))
         vmax = float(raw.get("@max"))
@@ -1476,7 +1489,7 @@ class FurunoStore(AbstractDataStore):
         dim = self.root.first_dimension
 
         data = indexing.LazilyOuterIndexedArray(FurunoArrayWrapper(var))
-        encoding = {"group": self._group}
+        encoding = {"group": self._group, "source": self._filename}
         if name == "PHIDP":
             add_offset = 360 * -32768 / 65535
             scale_factor = 360 / 65535
