@@ -115,7 +115,7 @@ def get_rb_data_layout(datadepth):
         datatype = byteorder + "u" + str(datawidth)
     else:
         raise ValueError(
-            "Wrong DataDepth: %d. " "Conversion only for depth 8, 16, 32" % datadepth
+            f"Wrong DataDepth: {datadepth}. Conversion only for depth 8, 16, 32."
         )
 
     return datawidth, datatype
@@ -141,9 +141,9 @@ def get_rb_data_attribute(xmldict, attr):
         sattr = int(xmldict["@" + attr])
     except KeyError:
         raise KeyError(
-            "Attribute @{0} is missing from "
+            f"Attribute @{attr} is missing from "
             "Blob Description. There may be some "
-            "problems with your file".format(attr)
+            "problems with your file"
         )
     return sattr
 
@@ -193,10 +193,10 @@ def get_rb_blob_data(datastring, blobid):
     xmltodict = util.import_optional("xmltodict")
 
     start = 0
-    search_string = '<BLOB blobid="{0}"'.format(blobid)
+    search_string = f'<BLOB blobid="{blobid}"'
     start = datastring.find(search_string.encode(), start)
     if start == -1:
-        raise EOFError("Blob ID {0} not found!".format(blobid))
+        raise EOFError(f"Blob ID {blobid} not found!")
     end = datastring.find(b">", start)
     xmlstring = datastring[start : end + 1]
 
@@ -220,7 +220,7 @@ def get_rb_blob_data(datastring, blobid):
     return data
 
 
-def map_rb_data(data, datadepth):
+def map_rb_data(data, datadepth, datashape=0):
     """Map BLOB data to correct DataWidth and Type and convert it
     to numpy array
 
@@ -230,6 +230,8 @@ def map_rb_data(data, datadepth):
         Blob Data
     datadepth : int
         bit depth of Blob data
+    datashape : tuple
+        expected data shape, only used for the flags to truncate
 
     Returns
     -------
@@ -247,7 +249,7 @@ def map_rb_data(data, datadepth):
     data = np.ndarray(shape=(int(len(data) / datawidth),), dtype=datatype, buffer=data)
 
     if flagdepth:
-        data = np.unpackbits(data)
+        data = np.unpackbits(data)[0 : np.prod(datashape)]
 
     return data
 
@@ -316,10 +318,11 @@ def get_rb_blob_from_string(datastring, blobdict):
     data = get_rb_blob_data(datastring, blobid)
     # map data to correct datatype and width
     datadepth = get_rb_data_attribute(blobdict, "depth")
-    data = map_rb_data(data, datadepth)
+    datashape = get_rb_data_shape(blobdict)
+    data = map_rb_data(data, datadepth, datashape)
 
     # reshape data
-    data.shape = get_rb_data_shape(blobdict)
+    data.shape = datashape
 
     return data
 
@@ -464,11 +467,11 @@ def read_rainbow(filename, loaddata=True):
     return rbdict
 
 
-class RainbowFileBase(object):
+class RainbowFileBase:
     """Base class for Rainbow Files."""
 
     def __init__(self, **kwargs):
-        super(RainbowFileBase, self).__init__()
+        super().__init__()
 
 
 class RainbowFile(RainbowFileBase):
@@ -491,7 +494,7 @@ class RainbowFile(RainbowFileBase):
                 "Rainbow5 reader currently doesn't support file-like objects"
             )
         self._data = None
-        super(RainbowFile, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         # read rainbow header
         self._header = get_rb_header(self._fh)["volume"]
         self._coordinates = None
@@ -546,7 +549,7 @@ class RainbowFile(RainbowFileBase):
                 "Rainbow5 data of type `poi` (pointmode) is currently not supported."
             )
         else:
-            raise TypeError("Unknown Rainbow File Type: {}".format(type))
+            raise TypeError(f"Unknown Rainbow File Type: {self.type}")
 
     @property
     def header(self):
