@@ -68,7 +68,7 @@ from wradlib.georef import xarray
 from wradlib.util import has_import, import_optional
 
 try:
-    from tqdm import tqdm
+    from tqdm.auto import tqdm
 except ImportError:
 
     def tqdm(val, **kwargs):
@@ -605,7 +605,7 @@ def to_cfradial2(volume, filename, timestep=None, engine=None):
             ds = ds.expand_dims("time")
         swp = ds.isel(time=timestep)
         swp.load()
-        dim0 = list(set(swp.dims) & {"azimuth", "elevation", "time"})[0]
+        dim0 = list(set(swp.dims) & {"azimuth", "elevation"})[0]
         try:
             swp = swp.swap_dims({dim0: "time"})
         except ValueError:
@@ -802,11 +802,14 @@ def to_odim(volume, filename, timestep=0):
 
 
 def _calculate_angle_res(dim):
-    angle_diff = np.diff(dim)
+    # need to sort dim first
+    angle_diff = np.diff(sorted(dim))
     angle_diff2 = np.abs(np.diff(angle_diff))
 
     # only select angle_diff, where angle_diff2 is less than 0.1 deg
-    angle_diff_wanted = angle_diff[:-1][angle_diff2 < 0.1]
+    # Todo: currently 0.05 is working in most cases
+    #  make this robust or parameterisable
+    angle_diff_wanted = angle_diff[:-1][angle_diff2 < 0.05]
     return np.round(np.nanmean(angle_diff_wanted), decimals=2)
 
 
@@ -1070,9 +1073,9 @@ class _OdimH5NetCDFMetadata:
         return a1gate
 
     def _get_site_coords(self):
-        lon = self._root["where"].attrs["lon"].item()
-        lat = self._root["where"].attrs["lat"].item()
-        alt = self._root["where"].attrs["height"].item()
+        lon = self._root["where"].attrs["lon"]
+        lat = self._root["where"].attrs["lat"]
+        alt = self._root["where"].attrs["height"]
         return lon, lat, alt
 
     def _get_dset_what(self):
@@ -1266,9 +1269,9 @@ class _GamicH5NetCDFMetadata:
         return start
 
     def _get_site_coords(self):
-        lon = self._root["where"].attrs["lon"].item()
-        lat = self._root["where"].attrs["lat"].item()
-        alt = self._root["where"].attrs["height"].item()
+        lon = self._root["where"].attrs["lon"]
+        lat = self._root["where"].attrs["lat"]
+        alt = self._root["where"].attrs["height"]
         return lon, lat, alt
 
 
@@ -1537,8 +1540,9 @@ def _assign_data_radial(root, sweep="sweep_1"):
     remove_vars = {}
     data = root.drop_vars(remove_vars)
     data.attrs = {}
-    start_idx = data.sweep_start_ray_index.values
-    end_idx = data.sweep_end_ray_index.values
+    # explicitely cast to int, as there are floats out in the wild
+    start_idx = data.sweep_start_ray_index.values.astype(int)
+    end_idx = data.sweep_end_ray_index.values.astype(int)
     ray_n_gates = data.get("ray_n_gates", False)
     ray_start_index = data.get("ray_start_index", False)
     data = data.drop_vars(
@@ -1570,14 +1574,14 @@ def _assign_data_radial(root, sweep="sweep_1"):
                 ray_start_index[start_idx[i]].values,
                 ray_start_index[start_idx[i]].values + current_rays_sum,
             )
-            rslice = slice(0, current_ray_n_gates[0].values.item())
+            rslice = slice(0, current_ray_n_gates[0].values)
             ds = ds.isel(range=rslice)
             ds = ds.isel(n_points=nslice).stack(n_points=["azimuth", "range"])
             ds = ds.unstack()
             # fix elevation/time additional range dimension in coordinate
             ds = ds.assign_coords({"elevation": ds.elevation.isel(range=0, drop=True)})
 
-        ds.attrs["fixed_angle"] = np.round(ds.fixed_angle.item(), decimals=1)
+        ds.attrs["fixed_angle"] = np.round(ds.fixed_angle.values, decimals=1)
         time = ds.rtime[0].reset_coords(drop=True)
         # get and delete "comment" attribute for time variable
         key = [key for key in time.attrs.keys() if "comment" in key]
@@ -1678,14 +1682,14 @@ def open_radar_dataset(filename_or_obj, engine=None, **kwargs):
     groups = []
     backend_kwargs = kwargs.pop("backend_kwargs", {})
 
-    if engine == "cfradial1":
-        groups = [None]
-    elif isinstance(group, (str, int)):
+    if isinstance(group, (str, int)):
         groups = [group]
     elif isinstance(group, list):
         pass
     else:
-        if engine == "cfradial2":
+        if engine == "cfradial1":
+            groups = ["/"]
+        elif engine == "cfradial2":
             groups = _get_nc4group_names(filename_or_obj, engine)
         elif engine in ["gamic", "odim"]:
             groups = _get_h5group_names(filename_or_obj, engine)
@@ -1713,11 +1717,13 @@ def open_radar_dataset(filename_or_obj, engine=None, **kwargs):
         for grp in groups
     ]
 
-    if engine == "cfradial1":
+    # cfradial1 backend always returns single group or root-object,
+    # from above we get back root-object in any case
+    if engine == "cfradial1" and not isinstance(group, str):
         ds = _assign_data_radial(ds[0], sweep=group)
 
     if group is None:
-        vol = RadarVolume()
+        vol = RadarVolume(engine=engine)
         vol.extend(ds)
         vol.sort(key=lambda x: x.time.min().values)
         ds = vol
@@ -1856,7 +1862,7 @@ def open_radar_mfdataset(paths, **kwargs):
     ]
 
     if len(ds) > 1:
-        vol = RadarVolume()
+        vol = RadarVolume(engine=engine)
         vol.extend(ds)
         vol.sort(key=lambda x: x.time.min().values)
         ds = vol
@@ -1911,6 +1917,7 @@ class RadarVolume(XRadBase):
         super().__init__()
         self._data = None
         self._root = None
+        self._engine = kwargs.pop("engine", "netcdf4")
         self._dims = {"azimuth": "elevation", "elevation": "azimuth"}
 
     def __repr__(self):
@@ -1918,7 +1925,7 @@ class RadarVolume(XRadBase):
         dims = "Dimension(s):"
         dims_summary = f"sweep: {len(self)}"
         summary.append(f"{dims} ({dims_summary})")
-        dim0 = list(set(self[0].dims) & {"azimuth", "elevation", "time"})[0]
+        dim0 = list(set(self[0].dims) & {"azimuth", "elevation"})[0]
         angle = f"{self._dims[dim0].capitalize()}(s):"
         angle_summary = [f"{v.attrs['fixed_angle']:.1f}" for v in self]
         angle_summary = ", ".join(angle_summary)
@@ -1938,14 +1945,14 @@ class RadarVolume(XRadBase):
             if "source" in v.encoding:
                 src = v.encoding["source"]
                 break
-        return xr.open_dataset(src, group=group).attrs
+        return xr.open_dataset(src, engine=self._engine, group=group).attrs
 
     def get_attr(self, sweep, group, attr):
         for v in self[sweep].variables.values():
             if "source" in v.encoding:
                 src = v.encoding["source"]
                 break
-        return xr.open_dataset(src, group=group).attrs[attr]
+        return xr.open_dataset(src, engine=self._engine, group=group).attrs[attr]
 
     def assign_root(self):
         """(Re-)Create root object according CfRadial2 standard"""
